aboutsummaryrefslogtreecommitdiff
path: root/src/argaze/GazeFeatures.py
diff options
context:
space:
mode:
Diffstat (limited to 'src/argaze/GazeFeatures.py')
-rw-r--r--src/argaze/GazeFeatures.py18
1 files changed, 9 insertions, 9 deletions
diff --git a/src/argaze/GazeFeatures.py b/src/argaze/GazeFeatures.py
index 3daea8f..1129849 100644
--- a/src/argaze/GazeFeatures.py
+++ b/src/argaze/GazeFeatures.py
@@ -351,11 +351,11 @@ class VisualScanStep():
return last_ts - first_ts
-VisualScanType = TypeVar('VisualScanType', bound="VisualScanType")
+VisualScanPathType = TypeVar('VisualScanPathType', bound="VisualScanPathType")
# Type definition for type annotation convenience
-class VisualScan(list):
- """List visual scan steps over successive aoi."""
+class VisualScanPath(list):
+ """List of visual scan steps over successive aoi."""
def __init__(self):
@@ -381,7 +381,7 @@ class VisualScan(list):
return output
def append_saccade(self, ts, saccade):
"""Append new saccade to visual scan."""
# Ignore saccade if no fixation have been stored before
if len(self.__movements) > 0:
@@ -389,7 +389,7 @@ class VisualScan(list):
self.__movements[ts] = saccade
def append_fixation(self, ts, fixation, looked_aoi: str) -> bool:
"""Append new fixation to visual scan and return last new visual scan step if one have been created.
.. warning::
It could raise VisualScanStepError"""
@@ -428,10 +428,10 @@ class VisualScan(list):
return None
-class VisualScanAnalyzer():
- """Abstract class to define what should provide a visual scan analyzer."""
+class VisualScanPathAnalyzer():
+ """Abstract class to define what should provide a visual scan path analyzer."""
- def analyze(self, visual_scan: VisualScanType) -> Any:
- """Analyze visual scan."""
+ def analyze(self, visual_scan_path: VisualScanPathType) -> Any:
+ """Analyze visual scan path."""
raise NotImplementedError('analyze() method not implemented')
@@ -381,7 +381,7 @@ class VisualScan(list):
return output
def append_saccade(self, ts, saccade):
- """Append new saccade to visual scan."""
+ """Append new saccade to visual scan path."""
# Ignore saccade if no fixation have been stored before
if len(self.__movements) > 0:
@@ -389,7 +389,7 @@ class VisualScan(list):
self.__movements[ts] = saccade
def append_fixation(self, ts, fixation, looked_aoi: str) -> bool:
- """Append new fixation to visual scan and return last new visual scan step if one have been created.
+ """Append new fixation to visual scan path and return last new visual scan step if one have been created.
.. warning::
It could raise VisualScanStepError"""